__version__ = '0.0.2'
__version_tuple__ = version_tuple = (0, 0, 2)
__title__ = 'revmap'
__description__ = (
    'Tool that generates reverse shell in multiple languages and encodes'
)
__url__ = 'https://github.com/joaoviictorti/revmap'
__author__ = 'joaoviictorti (viictorjj)'
__author_email__ = 'joaovictorti08@gmail.com'
__copyright__ = 'Copyright João Victor'
